==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property failureCodes Status codes in the response that indicate a failed login attempt.
 * @property successCodes Status codes in the response that indicate a successful login attempt.
 */
public data class
WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs(
    public val failureCodes: Output<List<Int>>,
    public val successCodes: Output<List<Int>>,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs> {
    override fun toJava():
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs.builder()
            .failureCodes(failureCodes.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .successCodes(successCodes.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs].
 */
@PulumiTagMarker
public class
WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgsBuilder
internal constructor() {
    private var failureCodes: Output<List<Int>>? = null

    private var successCodes: Output<List<Int>>? = null

    /**
     * @param value Status codes in the response that indicate a failed login attempt.
     */
    @JvmName("qoljvkqfsaqdahgp")
    public suspend fun failureCodes(`value`: Output<List<Int>>) {
        this.failureCodes = value
    }

    @JvmName("hvjysjvmxrjoxtrs")
    public suspend fun failureCodes(vararg values: Output<Int>) {
        this.failureCodes = Output.all(values.asList())
    }

    /**
     * @param values Status codes in the response that indicate a failed login attempt.
     */
    @JvmName("evqhgombabiarkvu")
    public suspend fun failureCodes(values: List<Output<Int>>) {
        this.failureCodes = Output.all(values)
    }

    /**
     * @param value Status codes in the response that indicate a successful login attempt.
     */
    @JvmName("pwcnbpbmnbpspqng")
    public suspend fun successCodes(`value`: Output<List<Int>>) {
        this.successCodes = value
    }

    @JvmName("uplkitgbglxgescr")
    public suspend fun successCodes(vararg values: Output<Int>) {
        this.successCodes = Output.all(values.asList())
    }

    /**
     * @param values Status codes in the response that indicate a successful login attempt.
     */
    @JvmName("xscrowrbjinyeihi")
    public suspend fun successCodes(values: List<Output<Int>>) {
        this.successCodes = Output.all(values)
    }

    /**
     * @param value Status codes in the response that indicate a failed login attempt.
     */
    @JvmName("xltttytmjmfjgwfq")
    public suspend fun failureCodes(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failureCodes = mapped
    }

    /**
     * @param values Status codes in the response that indicate a failed login attempt.
     */
    @JvmName("xedykuknkvtmyfwc")
    public suspend fun failureCodes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failureCodes = mapped
    }

    /**
     * @param value Status codes in the response that indicate a successful login attempt.
     */
    @JvmName("jamilpejmhtegben")
    public suspend fun successCodes(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.successCodes = mapped
    }

    /**
     * @param values Status codes in the response that indicate a successful login attempt.
     */
    @JvmName("tyqejxkubxfvbvhc")
    public suspend fun successCodes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.successCodes = mapped
    }

    internal fun build():
        WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs =
        WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs(
            failureCodes = failureCodes ?: throw PulumiNullFieldException("failureCodes"),
            successCodes = successCodes ?: throw PulumiNullFieldException("successCodes"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property failureCodes Status codes in the response that indicate a failed login attempt.
 * @property successCodes Status codes in the response that indicate a successful login attempt.
 */
public data class
WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs(
    public val failureCodes: Output<List<Int>>,
    public val successCodes: Output<List<Int>>,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs.builder()
            .failureCodes(failureCodes.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .successCodes(successCodes.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs].
 */
@PulumiTagMarker
public class
WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgsBuilder
internal constructor() {
    private var failureCodes: Output<List<Int>>? = null

    private var successCodes: Output<List<Int>>? = null

    /**
     * @param value Status codes in the response that indicate a failed login attempt.
     */
    @JvmName("boocuelxebmjussn")
    public suspend fun failureCodes(`value`: Output<List<Int>>) {
        this.failureCodes = value
    }

    @JvmName("kbqrraaosiqbfbfs")
    public suspend fun failureCodes(vararg values: Output<Int>) {
        this.failureCodes = Output.all(values.asList())
    }

    /**
     * @param values Status codes in the response that indicate a failed login attempt.
     */
    @JvmName("ejvlpthvmcwvrxfq")
    public suspend fun failureCodes(values: List<Output<Int>>) {
        this.failureCodes = Output.all(values)
    }

    /**
     * @param value Status codes in the response that indicate a successful login attempt.
     */
    @JvmName("alnysksdbvykkuqe")
    public suspend fun successCodes(`value`: Output<List<Int>>) {
        this.successCodes = value
    }

    @JvmName("fobxudmdyreovpwl")
    public suspend fun successCodes(vararg values: Output<Int>) {
        this.successCodes = Output.all(values.asList())
    }

    /**
     * @param values Status codes in the response that indicate a successful login attempt.
     */
    @JvmName("khckrtllifnmggth")
    public suspend fun successCodes(values: List<Output<Int>>) {
        this.successCodes = Output.all(values)
    }

    /**
     * @param value Status codes in the response that indicate a failed login attempt.
     */
    @JvmName("jqokdreaccrkbbrj")
    public suspend fun failureCodes(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failureCodes = mapped
    }

    /**
     * @param values Status codes in the response that indicate a failed login attempt.
     */
    @JvmName("qrmauehlycwowafp")
    public suspend fun failureCodes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failureCodes = mapped
    }

    /**
     * @param value Status codes in the response that indicate a successful login attempt.
     */
    @JvmName("itjhcmohrxipdjkd")
    public suspend fun successCodes(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.successCodes = mapped
    }

    /**
     * @param values Status codes in the response that indicate a successful login attempt.
     */
    @JvmName("civiqgewihlbmqtb")
    public suspend fun successCodes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.successCodes = mapped
    }

    internal fun build(): WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs =
        WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionStatusCodeArgs(
            failureCodes = failureCodes ?: throw PulumiNullFieldException("failureCodes"),
            successCodes = successCodes ?: throw PulumiNullFieldException("successCodes"),
        )
}
